==> knative-model-4.4.1-sources.jar: annotations/io/fabric8/knative/messaging/v1alpha1/InMemoryChannelFluent.java <==
package io.fabric8.knative.messaging.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import javax.validation.constraints.NotNull;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import javax.validation.Valid;
import java.lang.Object;
import java.util.Map;

public interface InMemoryChannelFluent<A extends InMemoryChannelFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public InMemoryChannelFluent.MetadataNested<A> withNewMetadata();
    public InMemoryChannelFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public InMemoryChannelFluent.MetadataNested<A> editMetadata();
    public InMemoryChannelFluent.MetadataNested<A> editOrNewMetadata();
    public InMemoryChannelFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public InMemoryChannelSpec getSpec();
    public InMemoryChannelSpec buildSpec();
    public A withSpec(InMemoryChannelSpec spec);
    public Boolean hasSpec();
    public InMemoryChannelFluent.SpecNested<A> withNewSpec();
    public InMemoryChannelFluent.SpecNested<A> withNewSpecLike(InMemoryChannelSpec item);
    public InMemoryChannelFluent.SpecNested<A> editSpec();
    public InMemoryChannelFluent.SpecNested<A> editOrNewSpec();
    public InMemoryChannelFluent.SpecNested<A> editOrNewSpecLike(InMemoryChannelSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public InMemoryChannelStatus getStatus();
    public InMemoryChannelStatus buildStatus();
    public A withStatus(InMemoryChannelStatus status);
    public Boolean hasStatus();
    public InMemoryChannelFluent.StatusNested<A> withNewStatus();
    public InMemoryChannelFluent.StatusNested<A> withNewStatusLike(InMemoryChannelStatus item);
    public InMemoryChannelFluent.StatusNested<A> editStatus();
    public InMemoryChannelFluent.StatusNested<A> editOrNewStatus();
    public InMemoryChannelFluent.StatusNested<A> editOrNewStatusLike(InMemoryChannelStatus item);

    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<InMemoryChannelFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,InMemoryChannelSpecFluent<InMemoryChannelFluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}
    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,InMemoryChannelStatusFluent<InMemoryChannelFluent.StatusNested<N>>{

        
    public N and();    public N endStatus();
}


}

==> knative-model-4.10.1-sources.jar: annotations/io/fabric8/knative/messaging/v1alpha1/InMemoryChannelFluent.java <==
package io.fabric8.knative.messaging.v1alpha1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface InMemoryChannelFluent<A extends InMemoryChannelFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public InMemoryChannelFluent.MetadataNested<A> withNewMetadata();
    public InMemoryChannelFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public InMemoryChannelFluent.MetadataNested<A> editMetadata();
    public InMemoryChannelFluent.MetadataNested<A> editOrNewMetadata();
    public InMemoryChannelFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public InMemoryChannelSpec getSpec();
    public InMemoryChannelSpec buildSpec();
    public A withSpec(InMemoryChannelSpec spec);
    public Boolean hasSpec();
    public InMemoryChannelFluent.SpecNested<A> withNewSpec();
    public InMemoryChannelFluent.SpecNested<A> withNewSpecLike(InMemoryChannelSpec item);
    public InMemoryChannelFluent.SpecNested<A> editSpec();
    public InMemoryChannelFluent.SpecNested<A> editOrNewSpec();
    public InMemoryChannelFluent.SpecNested<A> editOrNewSpecLike(InMemoryChannelSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public InMemoryChannelStatus getStatus();
    public InMemoryChannelStatus buildStatus();
    public A withStatus(InMemoryChannelStatus status);
    public Boolean hasStatus();
    public InMemoryChannelFluent.StatusNested<A> withNewStatus();
    public InMemoryChannelFluent.StatusNested<A> withNewStatusLike(InMemoryChannelStatus item);
    public InMemoryChannelFluent.StatusNested<A> editStatus();
    public InMemoryChannelFluent.StatusNested<A> editOrNewStatus();
    public InMemoryChannelFluent.StatusNested<A> editOrNewStatusLike(InMemoryChannelStatus item);

    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<InMemoryChannelFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,InMemoryChannelSpecFluent<InMemoryChannelFluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}
    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,InMemoryChannelStatusFluent<InMemoryChannelFluent.StatusNested<N>>{

        
    public N and();    public N endStatus();
}


}
